@@ -18,8 +18,10 @@ class CLIUsageCommand(Command):
             for command in folder['commands']:
                 print('### ' + command + '\n')
                 cli_command = "symbol-cli " + folder['title'] + " " + command + " -h"
-                process = subprocess.run(cli_command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-                print(process.stdout)
+                process = subprocess.Popen(cli_command, shell=True, text=True, stdout=subprocess.PIPE,
+                                           stderr=subprocess.STDOUT, universal_newlines=True)
+                out = process.communicate()[0]
+                print(out.decode('utf-8'))
 
     def execute(self):
         """Contains all the logic to execute a command."""
